@@ -2,18 +2,23 @@
 
 from argparse import ArgumentParser, Namespace
 from logging import INFO, basicConfig, getLogger
+from pathlib import Path
 from socket import timeout
 from sys import exit    # pylint: disable=W0622
 
+from rcon.errorhandler import ErrorHandler
 from rcon.rconclt import get_credentials
+from rcon.config import CONFIG_FILE, LOG_FORMAT
 from rcon.console import rconcmd
 
 
 __all__ = ['get_args', 'main']
 
-
+ERRORS = (
+    (ConnectionRefusedError, 'Connection refused.', 3),
+    (timeout, 'Connection timeout.', 4)
+)
 LOGGER = getLogger('rconshell')
-LOG_FORMAT = '[%(levelname)s] %(name)s: %(message)s'
 
 
 def get_args() -> Namespace:
@@ -21,6 +26,8 @@ def get_args() -> Namespace:
 
     parser = ArgumentParser(description='An interactive RCON shell.')
     parser.add_argument('server', nargs='?', help='the server to connect to')
+    parser.add_argument('-c', '--config', type=Path, metavar='file',
+                        default=CONFIG_FILE, help='the configuration file')
     parser.add_argument('-p', '--prompt', default='RCON> ', metavar='PS1',
                         help='the shell prompt')
     return parser.parse_args()
@@ -32,18 +39,12 @@ def main():
     args = get_args()
     basicConfig(level=INFO, format=LOG_FORMAT)
 
-    if server := args.server:
-        host, port, passwd = get_credentials(server)
+    if args.server:
+        host, port, passwd = get_credentials(args)
     else:
         host = port = passwd = None
 
-    try:
+    with ErrorHandler(ERRORS, LOGGER):
         exit_code = rconcmd(host, port, passwd, args.prompt)
-    except ConnectionRefusedError:
-        LOGGER.error('Connection refused.')
-        exit(3)
-    except timeout:
-        LOGGER.error('Connection timeout.')
-        exit(4)
 
     exit(exit_code)
